/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ClassMapping.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.xmlconfig.mapping;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Defines a mapping for a given class.
 * @author Florent Benoit
 */
public class ClassMapping extends AbsMapping {

    /**
     * Association between a name(or alias) and an attribute mapping.
     */
    private Map<String, AttributeMapping> attributesMapping = null;


    /**
     * The text of this element must be set on an attribute.
     */
    private String elementAttribute = null;


    /**
     * @return the name of the attribute to use when finding a value inside this element.
     */
    public String getElementAttribute() {
        return elementAttribute;
    }

    /**
     * Sets the name of the element attribute for this class.
     * @param elementAttribute the value of the attribute to map the XML element.
     */
    public void setElementAttribute(final String elementAttribute) {
        this.elementAttribute = elementAttribute;
    }

    /**
     * Build a default class mapping.
     */
    public ClassMapping() {
        super();
        this.attributesMapping = new HashMap<String, AttributeMapping>();
    }

    /**
     * Add a given attribute mapping object.
     * @param attributeMapping the given attribute.
     */
    public void addAttributeMapping(final AttributeMapping attributeMapping) {
        attributesMapping.put(attributeMapping.getName(), attributeMapping);

        // Always non-null list (but may be empty)
        List<String> aliases = attributeMapping.getAliases();

        // store alias too (if any)
        if (!aliases.isEmpty()) {
            for (String alias : aliases) {
                attributesMapping.put(alias, attributeMapping);
            }
        }
    }

    /**
     * Gets the attribute mapping for the given attribute name.
     * @param attributeName the given attribute name.
     * @return the attribute mapping or null if not found.
     */
    public AttributeMapping getAttributeMapping(final String attributeName) {
        return attributesMapping.get(attributeName);
    }

    /**
     * Returns a string representation of the object.
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        sb.append("[");
        sb.append(super.toString());
        sb.append(", attributes=");
        sb.append(attributesMapping);
        sb.append("]");

        return sb.toString();
    }

}
