/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: InputStreamConfigurationSource.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.xmlconfig.source;

import java.io.InputStream;

import org.ow2.util.xml.DocumentParser;
import org.ow2.util.xml.DocumentParserException;
import org.w3c.dom.Document;

/**
 * This {@link IConfigurationSource} wraps an {@link InputStream}.
 * @author Guillaume Sauthier
 */
public class InputStreamConfigurationSource implements IConfigurationSource {

    /**
     * Name of the stream.
     */
    private String name;

    /**
     * Stream.
     */
    private InputStream stream;

    /**
     * Constructs a new {@link IConfigurationSource} based on {@link InputStream}.
     * @param name stream's name
     * @param stream the stream to be parsed
     */
    public InputStreamConfigurationSource(final String name, final InputStream stream) {
        this.name = name;
        this.stream = stream;
    }

    /**
     * Parse the configuration source's content.
     * @param validating is the parser validating ?
     * @return the parsed Document
     * @throws DocumentParserException if the document cannot be parsed or is not valid.
     */
    public Document getDocument(final boolean validating) throws DocumentParserException {
        return DocumentParser.getDocument(stream, validating, null);
    }

    /**
     * @return the name of the source (useful for textual representation).
     */
    public String getName() {
        return name;
    }

}
